@@ -394,6 +394,9 @@ def make_operator_type_error(operator, arg_one_type, arg_two_type):
         to_fix
     )
 
+def get_recent_traceback():
+    return traceback.format_exc()
+
 def get_recent_traceback_as_list():
     """
     Helper function for getting the traceback of the most recent error.
