@@ -169,9 +169,15 @@ def identify():
     feedbacks = get_user_field('feedbacks')
     local = is_local_deployment()
 
+    try:
+        from jupyterlab import __version__ as jupyterlab_version
+    except:
+        jupyterlab_version = 'No JupyterLab'
+    
     analytics.identify(static_user_id, {
         'python_version': sys.version_info,
         'mito_version': __version__,
+        'jupyterlab_version': jupyterlab_version,
         'email': user_email,
         'local': local,
         'intended_behavior': intended_behavior,
@@ -251,19 +257,27 @@ def log_event_processed(event, widget_state_container, failed=False, edit_error=
 
         # We also check there is an edit_error, and if there is, then we add the error logs
         if edit_error is not None:
+            recent_traceback = get_recent_traceback_as_list()
             error_properties = {
                 'error_type': edit_error.type_,
                 'error_header': edit_error.header,
                 'error_to_fix': edit_error.to_fix,
-                'error_traceback': get_recent_traceback_as_list(),
+                'error_traceback': recent_traceback,
+                # We get the last line of the error as it makes it much easier
+                # to easily analyze on error messages 
+                'error_traceback_last_line': recent_traceback[-1],
             }
         elif failed:
             # Otherwise, if there is no edit_error, and we still failed, then we must have
             # gotten an execution error
+            recent_traceback = get_recent_traceback_as_list()
             error_properties = {
                 'error_type': 'execution_error',
                 'error_header': 'Execution Error',
-                'error_traceback': get_recent_traceback_as_list(),
+                'error_traceback': recent_traceback,
+                # We get the last line of the error as it makes it much easier
+                # to easily analyze on error messages
+                'error_traceback_last_line': recent_traceback[-1],
             }
         else:
             error_properties = {}
